==> pid_0.2.20080916-1.tar.gz: pid-0.2.20080916/src/View/Location.cpp <==
#include "Location.h"

#include "../Database.h"

#include "../Data/Location.h"

#include <Lum/Base/Util.h>

#include <Lum/Model/Selection.h>

#include <Lum/Label.h>

#include <iostream>

namespace Views {

  Location::Location()
  : DataView(L"Location")
  {
    street=new Lum::Model::String();
    city=new Lum::Model::String();
    zip=new Lum::Model::String();
    state=new Lum::Model::String();
    country=new Lum::Model::String();

    RegisterModel(street);
    RegisterModel(city);
    RegisterModel(zip);
    RegisterModel(state);
    RegisterModel(country);
  }

  void Location::RegisterDataViews(Lum::Tab*& tab)
  {
    Lum::Label  *label;
    Lum::String *string;

    panel=new Lum::VPanel();
    panel->SetFlex(true,true);

    label=new Lum::Label();
    label->SetFlex(true,false);

    string=new Lum::String();
    string->SetFlex(true,false);
    string->SetModel(street);
    label->AddLabel(L"Street",string);

    string=new Lum::String();
    string->SetFlex(true,false);
    string->SetModel(city);
    label->AddLabel(L"City",string);

    string=new Lum::String();
    string->SetFlex(true,false);
    string->SetModel(zip);
    label->AddLabel(L"ZIP",string);

    string=new Lum::String();
    string->SetFlex(true,false);
    string->SetModel(state);
    label->AddLabel(L"State",string);

    string=new Lum::String();
    string->SetFlex(true,false);
    string->SetModel(country);
    label->AddLabel(L"Country",string);

    panel->Add(label);

    tab->Add(L"Location",panel);

    DataView::RegisterDataViews(tab);
  }

  void Location::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
  {
    if (model==saveAction && saveAction->IsFinished()) {
      if (!location->IsRegistered()) {
        database->Insert(location);

        if (viewData->RequestsLink()) {
          viewData->linkData->LinkData(viewData->linkName,location);
          viewData->ClearLinkInfo();
          RefreshLinkTable();
        }
      }
      Save();
    }
    else if (IsRegisteredModel(model)) {
      if (!city->Empty()) {
        saveAction->Enable();
      }
      else {
        saveAction->Disable();
      }
    }
    else {
      DataView::Resync(model,msg);
    }
  }

  void Location::Load(DataPtr viewData)
  {
    SetViewData(viewData);

    location=dynamic_cast< ::Data::Location*>(viewData->data);

    assert(location!=NULL);

    street->Set(location->street);
    city->Set(location->city);
    zip->Set(location->zip);
    state->Set(location->state);
    country->Set(location->country);

    DataView::Load(viewData);
  }

  void Location::Vanish()
  {
    DataView::Vanish();

    location=NULL;
  }

  void Location::Save()
  {
    location->street=street->Get();
    location->city=city->Get();
    location->zip=zip->Get();
    location->state=state->Get();
    location->country=country->Get();
  }
}

==> pid_0.2.20101005-2.tar.gz: pid-0.2.20101005/src/View/Location.cpp <==
#include "Location.h"

#include "../Database.h"

#include "../Data/Location.h"

#include <Lum/Base/Util.h>

#include <Lum/Model/Selection.h>

#include <Lum/Label.h>

#include <iostream>

namespace Views {

  Location::Location()
  : DataView(L"Location")
  {
    street=new Lum::Model::String();
    city=new Lum::Model::String();
    zip=new Lum::Model::String();
    state=new Lum::Model::String();
    country=new Lum::Model::String();

    RegisterModel(street);
    RegisterModel(city);
    RegisterModel(zip);
    RegisterModel(state);
    RegisterModel(country);
  }

  void Location::RegisterDataViews(Lum::Tab*& tab)
  {
    tab->Add(L"Location",
             Lum::VPanel::Create(true,true)
             ->Add(Lum::Label::Create(true,false)
                   ->AddLabel(L"Street",Lum::String::Create(street,true,false))
                   ->AddLabel(L"City",Lum::String::Create(city,true,false))
                   ->AddLabel(L"ZIP",Lum::String::Create(zip,true,false))
                   ->AddLabel(L"State",Lum::String::Create(state,true,false))
                   ->AddLabel(L"Country",Lum::String::Create(country,true,false))));

    DataView::RegisterDataViews(tab);
  }

  void Location::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
  {
    if (model==saveAction && saveAction->IsFinished()) {
      if (!location->IsRegistered()) {
        database->Insert(location);

        if (viewData->RequestsLink()) {
          viewData->linkData->LinkData(viewData->linkName,location);
          viewData->ClearLinkInfo();
          RefreshLinkTable();
        }
      }
      Save();
    }
    else if (IsRegisteredModel(model)) {
      if (!city->Empty()) {
        saveAction->Enable();
      }
      else {
        saveAction->Disable();
      }
    }
    else {
      DataView::Resync(model,msg);
    }
  }

  void Location::Load(DataPtr viewData)
  {
    SetViewData(viewData);

    location=dynamic_cast< ::Data::Location*>(viewData->data);

    assert(location!=NULL);

    street->Set(location->street);
    city->Set(location->city);
    zip->Set(location->zip);
    state->Set(location->state);
    country->Set(location->country);

    DataView::Load(viewData);
  }

  void Location::Vanish()
  {
    DataView::Vanish();

    location=NULL;
  }

  void Location::Save()
  {
    location->street=street->Get();
    location->city=city->Get();
    location->zip=zip->Get();
    location->state=state->Get();
    location->country=country->Get();
  }
}
